You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by vi...@apache.org on 2016/04/18 04:34:36 UTC

[1/2] mesos git commit: Slave rename - Updated strings in error messages and other strings.

Repository: mesos
Updated Branches:
  refs/heads/master e24c2b242 -> 5c1782b00


Slave rename - Updated strings in error messages and other strings.

This patch renames 'slave' to 'agent' in the following strings:
1. Error/Warning messages
2. Flag help/description messages
3. Test case messages
4. Other standard output messages

Review: https://reviews.apache.org/r/46189/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/02c00e2c
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/02c00e2c
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/02c00e2c

Branch: refs/heads/master
Commit: 02c00e2cb08362a86fb378e7ef7aeb1229a80ac1
Parents: e24c2b2
Author: zhou xing <xi...@cn.ibm.com>
Authored: Sun Apr 17 19:33:34 2016 -0700
Committer: Vinod Kone <vi...@gmail.com>
Committed: Sun Apr 17 19:33:34 2016 -0700

----------------------------------------------------------------------
 CHANGELOG                                       |  2 +
 src/common/resources_utils.cpp                  |  2 +-
 src/examples/dynamic_reservation_framework.cpp  |  2 +-
 src/hook/manager.cpp                            | 18 +++---
 src/internal/devolve.cpp                        |  2 +-
 src/local/flags.hpp                             |  2 +-
 src/logging/flags.cpp                           |  4 +-
 src/master/flags.cpp                            | 44 +++++++-------
 src/master/http.cpp                             | 36 +++++------
 src/master/master.cpp                           | 34 +++++------
 src/master/master.hpp                           |  6 +-
 src/master/validation.cpp                       | 10 +--
 .../executor/mesos_executor_driver_impl.cpp     |  2 +-
 .../scheduler/mesos_scheduler_driver_impl.cpp   |  2 +-
 src/scaling/scaling_sched.py                    |  4 +-
 src/sched/sched.cpp                             |  2 +-
 .../mesos/isolators/network/port_mapping.cpp    |  4 +-
 src/slave/flags.cpp                             | 64 ++++++++++----------
 src/slave/http.cpp                              | 10 +--
 src/slave/main.cpp                              | 14 ++---
 src/slave/slave.cpp                             | 18 +++---
 src/slave/state.cpp                             |  6 +-
 src/tests/cluster.cpp                           |  8 +--
 .../docker_containerizer_tests.cpp              |  2 +-
 .../containerizer/filesystem_isolator_tests.cpp |  2 +-
 src/tests/flags.hpp                             |  4 +-
 src/tests/hierarchical_allocator_tests.cpp      |  6 +-
 src/tests/master_allocator_tests.cpp            |  4 +-
 src/tests/master_tests.cpp                      |  2 +-
 src/tests/paths_tests.cpp                       |  2 +-
 src/tests/slave_recovery_tests.cpp              |  6 +-
 src/tests/sorter_tests.cpp                      | 24 ++++----
 32 files changed, 175 insertions(+), 173 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index 915c592..d2e902f 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -71,6 +71,8 @@ Binary API Changes:
   * [MESOS-5055] - Replace Master/Slave Terminology Phase I - Update strings in
     the log message and standard output
   * [MESOS-3782] - Replace Master/Slave Terminology Phase I - Duplicate/Rename binaries.
+  * [MESOS-5057] - Replace Master/Slave Terminology Phase I - Update strings in
+    error messages and other strings
 
 
 Release Notes - Mesos - Version 0.28.1

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/common/resources_utils.cpp
----------------------------------------------------------------------
diff --git a/src/common/resources_utils.cpp b/src/common/resources_utils.cpp
index 70e6f02..8e881a0 100644
--- a/src/common/resources_utils.cpp
+++ b/src/common/resources_utils.cpp
@@ -70,7 +70,7 @@ Try<Resources> applyCheckpointedResources(
 
     if (!totalResources.contains(stripped)) {
       return Error(
-          "Incompatible slave resources: " + stringify(totalResources) +
+          "Incompatible agent resources: " + stringify(totalResources) +
           " does not contain " + stringify(stripped));
     }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/examples/dynamic_reservation_framework.cpp
----------------------------------------------------------------------
diff --git a/src/examples/dynamic_reservation_framework.cpp b/src/examples/dynamic_reservation_framework.cpp
index 8f00bcf..81ad386 100644
--- a/src/examples/dynamic_reservation_framework.cpp
+++ b/src/examples/dynamic_reservation_framework.cpp
@@ -201,7 +201,7 @@ public:
       // Mark state of slave as RESERVED, so other tasks can reuse it.
       CHECK(states[status.slave_id()] == State::TASK_RUNNING);
       states[status.slave_id()] = State::RESERVED;
-      LOG(INFO) << "Task " << taskId << " is finished at slave "
+      LOG(INFO) << "Task " << taskId << " is finished at agent "
                 << status.slave_id();
     } else {
       LOG(INFO) << "Task " << taskId << " is in state " << status.state();

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/hook/manager.cpp
----------------------------------------------------------------------
diff --git a/src/hook/manager.cpp b/src/hook/manager.cpp
index 692b9ea..381807d 100644
--- a/src/hook/manager.cpp
+++ b/src/hook/manager.cpp
@@ -139,7 +139,7 @@ void HookManager::masterSlaveLostHook(const SlaveInfo& slaveInfo)
     Hook* hook = availableHooks[name];
     Try<Nothing> result = hook->masterSlaveLostHook(slaveInfo);
     if (result.isError()) {
-      LOG(WARNING) << "Master slave-lost hook failed for module '"
+      LOG(WARNING) << "Master agent-lost hook failed for module '"
                    << name << "': " << result.error();
     }
   }
@@ -165,7 +165,7 @@ Labels HookManager::slaveRunTaskLabelDecorator(
       if (result.isSome()) {
         taskInfo_.mutable_labels()->CopyFrom(result.get());
       } else if (result.isError()) {
-        LOG(WARNING) << "Slave label decorator hook failed for module '"
+        LOG(WARNING) << "Agent label decorator hook failed for module '"
                     << name << "': " << result.error();
       }
     }
@@ -190,7 +190,7 @@ Environment HookManager::slaveExecutorEnvironmentDecorator(
         executorInfo.mutable_command()->mutable_environment()->CopyFrom(
             result.get());
       } else if (result.isError()) {
-        LOG(WARNING) << "Slave environment decorator hook failed for module '"
+        LOG(WARNING) << "Agent environment decorator hook failed for module '"
                     << name << "': " << result.error();
       }
     }
@@ -225,7 +225,7 @@ void HookManager::slavePreLaunchDockerHook(
           resources,
           env);
     if (result.isError()) {
-      LOG(WARNING) << "Slave pre launch docker hook failed for module '"
+      LOG(WARNING) << "Agent pre launch docker hook failed for module '"
                    << name << "': " << result.error();
     }
   }
@@ -240,7 +240,7 @@ void HookManager::slavePostFetchHook(
     Hook* hook = availableHooks[name];
     Try<Nothing> result = hook->slavePostFetchHook(containerId, directory);
     if (result.isError()) {
-      LOG(WARNING) << "Slave post fetch hook failed for module "
+      LOG(WARNING) << "Agent post fetch hook failed for module "
                    << "'" << name << "': " << result.error();
     }
   }
@@ -256,7 +256,7 @@ void HookManager::slaveRemoveExecutorHook(
     const Try<Nothing> result =
       hook->slaveRemoveExecutorHook(frameworkInfo, executorInfo);
     if (result.isError()) {
-      LOG(WARNING) << "Slave remove executor hook failed for module '"
+      LOG(WARNING) << "Agent remove executor hook failed for module '"
                    << name << "': " << result.error();
     }
   }
@@ -285,7 +285,7 @@ TaskStatus HookManager::slaveTaskStatusDecorator(
               result.get().container_status());
         }
       } else if (result.isError()) {
-        LOG(WARNING) << "Slave TaskStatus decorator hook failed for "
+        LOG(WARNING) << "Agent TaskStatus decorator hook failed for "
                      << "module '" << name << "': " << result.error();
       }
     }
@@ -313,7 +313,7 @@ Resources HookManager::slaveResourcesDecorator(
       if (result.isSome()) {
         slaveInfo_.mutable_resources()->CopyFrom(result.get());
       } else if (result.isError()) {
-        LOG(WARNING) << "Slave Resources decorator hook failed for "
+        LOG(WARNING) << "Agent Resources decorator hook failed for "
                      << "module '" << name << "': " << result.error();
       }
     }
@@ -341,7 +341,7 @@ Attributes HookManager::slaveAttributesDecorator(
       if (result.isSome()) {
         slaveInfo_.mutable_attributes()->CopyFrom(result.get());
       } else if (result.isError()) {
-        LOG(WARNING) << "Slave Attributes decorator hook failed for "
+        LOG(WARNING) << "Agent Attributes decorator hook failed for "
                      << "module '" << name << "': " << result.error();
       }
     }

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/internal/devolve.cpp
----------------------------------------------------------------------
diff --git a/src/internal/devolve.cpp b/src/internal/devolve.cpp
index 0f58dc1..4233246 100644
--- a/src/internal/devolve.cpp
+++ b/src/internal/devolve.cpp
@@ -65,7 +65,7 @@ SlaveInfo devolve(const v1::AgentInfo& agentInfo)
   SlaveInfo info = devolve<SlaveInfo>(agentInfo);
 
   // We set 'checkpoint' to 'true' since the v1::AgentInfo doesn't
-  // have 'checkpoint' but all "slaves" were checkpointing by default
+  // have 'checkpoint' but all "agents" were checkpointing by default
   // when v1::AgentInfo was introduced. See MESOS-2317.
   info.set_checkpoint(true);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/local/flags.hpp
----------------------------------------------------------------------
diff --git a/src/local/flags.hpp b/src/local/flags.hpp
index b3cd811..f0af0d2 100644
--- a/src/local/flags.hpp
+++ b/src/local/flags.hpp
@@ -32,7 +32,7 @@ public:
   {
     add(&Flags::num_slaves,
         "num_slaves",
-        "Number of slaves to launch for local cluster",
+        "Number of agents to launch for local cluster",
         1);
   }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/logging/flags.cpp
----------------------------------------------------------------------
diff --git a/src/logging/flags.cpp b/src/logging/flags.cpp
index 446eb92..f64ad5e 100644
--- a/src/logging/flags.cpp
+++ b/src/logging/flags.cpp
@@ -48,10 +48,10 @@ mesos::internal::logging::Flags::Flags()
 
   add(&Flags::initialize_driver_logging,
       "initialize_driver_logging",
-      "Whether the master/slave should initialize Google logging for the\n"
+      "Whether the master/agent should initialize Google logging for the\n"
       "Mesos scheduler and executor drivers, in same way as described here.\n"
       "The scheduler/executor drivers have separate logs and do not get\n"
-      "written to the master/slave logs.\n\n"
+      "written to the master/agent logs.\n\n"
       "This option has no effect when using the HTTP scheduler/executor APIs.\n"
       "By default, this option is true.",
       true);

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/master/flags.cpp
----------------------------------------------------------------------
diff --git a/src/master/flags.cpp b/src/master/flags.cpp
index 989bc98..e6a239c 100644
--- a/src/master/flags.cpp
+++ b/src/master/flags.cpp
@@ -35,7 +35,7 @@ mesos::internal::master::Flags::Flags()
       "hostname",
       "The hostname the master should advertise in ZooKeeper.\n"
       "If left unset, the hostname is resolved from the IP address\n"
-      "that the slave binds to; unless the user explicitly prevents\n"
+      "that the agent binds to; unless the user explicitly prevents\n"
       "that, using `--no-hostname_lookup`, in which case the IP itself\n"
       "is used.");
 
@@ -85,7 +85,7 @@ mesos::internal::master::Flags::Flags()
       "Whether the master will take actions based on the persistent\n"
       "information stored in the Registry. Setting this to false means\n"
       "that the Registrar will never reject the admission, readmission,\n"
-      "or removal of a slave. Consequently, `false` can be used to\n"
+      "or removal of an agent. Consequently, `false` can be used to\n"
       "bootstrap the persistent state on a running cluster.\n"
       "NOTE: This flag is *experimental* and should not be used in\n"
       "production yet.",
@@ -112,8 +112,8 @@ mesos::internal::master::Flags::Flags()
 
   add(&Flags::slave_reregister_timeout,
       "slave_reregister_timeout",
-      "The timeout within which all slaves are expected to re-register\n"
-      "when a new master is elected as the leader. Slaves that do not\n"
+      "The timeout within which all agents are expected to re-register\n"
+      "when a new master is elected as the leader. Agents that do not\n"
       "re-register within the timeout will be removed from the registry\n"
       "and will be shutdown if they attempt to communicate with master.\n"
       "NOTE: This value has to be at least " +
@@ -124,16 +124,16 @@ mesos::internal::master::Flags::Flags()
   // TODO(bmahler): Add a `--production` flag for production defaults.
   add(&Flags::recovery_slave_removal_limit,
       "recovery_slave_removal_limit",
-      "For failovers, limit on the percentage of slaves that can be removed\n"
+      "For failovers, limit on the percentage of agents that can be removed\n"
       "from the registry *and* shutdown after the re-registration timeout\n"
       "elapses. If the limit is exceeded, the master will fail over rather\n"
-      "than remove the slaves.\n"
+      "than remove the agents.\n"
       "This can be used to provide safety guarantees for production\n"
       "environments. Production environments may expect that across master\n"
-      "failovers, at most a certain percentage of slaves will fail\n"
+      "failovers, at most a certain percentage of agents will fail\n"
       "permanently (e.g. due to rack-level failures).\n"
       "Setting this limit would ensure that a human needs to get\n"
-      "involved should an unexpected widespread failure of slaves occur\n"
+      "involved should an unexpected widespread failure of agents occur\n"
       "in the cluster.\n"
       "Values: [0%-100%]",
       stringify(RECOVERY_SLAVE_REMOVAL_PERCENT_LIMIT * 100.0) + "%");
@@ -142,10 +142,10 @@ mesos::internal::master::Flags::Flags()
   // corresponding parser for flags.
   add(&Flags::slave_removal_rate_limit,
       "slave_removal_rate_limit",
-      "The maximum rate (e.g., `1/10mins`, `2/3hrs`, etc) at which slaves\n"
+      "The maximum rate (e.g., `1/10mins`, `2/3hrs`, etc) at which agents\n"
       "will be removed from the master when they fail health checks.\n"
-      "By default, slaves will be removed as soon as they fail the health\n"
-      "checks. The value is of the form `(Number of slaves)/(Duration)`.");
+      "By default, agents will be removed as soon as they fail the health\n"
+      "checks. The value is of the form `(Number of agents)/(Duration)`.");
 
   add(&Flags::webui_dir,
       "webui_dir",
@@ -154,9 +154,9 @@ mesos::internal::master::Flags::Flags()
 
   add(&Flags::whitelist,
       "whitelist",
-      "Path to a file which contains a list of slaves (one per line) to\n"
+      "Path to a file which contains a list of agents (one per line) to\n"
       "advertise offers for. The file is watched, and periodically re-read to\n"
-      "refresh the slave whitelist. By default there is no whitelist / all\n"
+      "refresh the agent whitelist. By default there is no whitelist / all\n"
       "machines are accepted. Path could be of the form\n"
       "`file:///path/to/file` or `/path/to/file`.\n");
 
@@ -209,8 +209,8 @@ mesos::internal::master::Flags::Flags()
 
   add(&Flags::authenticate_slaves,
       "authenticate_slaves",
-      "If `true`, only authenticated slaves are allowed to register.\n"
-      "If `false`, unauthenticated slaves are also allowed to register.",
+      "If `true`, only authenticated agents are allowed to register.\n"
+      "If `false`, unauthenticated agents are also allowed to register.",
       false);
 
   add(&Flags::authenticate_http,
@@ -334,10 +334,10 @@ mesos::internal::master::Flags::Flags()
 #ifdef WITH_NETWORK_ISOLATOR
   add(&Flags::max_executors_per_slave,
       "max_executors_per_slave",
-      "Maximum number of executors allowed per slave. The network\n"
+      "Maximum number of executors allowed per agent. The network\n"
       "monitoring/isolation technique imposes an implicit resource\n"
       "acquisition on each executor (# ephemeral ports), as a result\n"
-      "one can only run a certain number of executors on each slave.");
+      "one can only run a certain number of executors on each agent.");
 #endif // WITH_NETWORK_ISOLATOR
 
   // TODO(karya): When we have optimistic offers, this will only
@@ -399,7 +399,7 @@ mesos::internal::master::Flags::Flags()
   add(&Flags::authenticators,
       "authenticators",
       "Authenticator implementation to use when authenticating frameworks\n"
-      "and/or slaves. Use the default `" + string(DEFAULT_AUTHENTICATOR) + "`\n"
+      "and/or agents. Use the default `" + string(DEFAULT_AUTHENTICATOR) + "`\n"
       "or load an alternate authenticator module using `--modules`.",
       DEFAULT_AUTHENTICATOR);
 
@@ -417,8 +417,8 @@ mesos::internal::master::Flags::Flags()
 
   add(&Flags::slave_ping_timeout,
       "slave_ping_timeout",
-      "The timeout within which each slave is expected to respond to a\n"
-      "ping from the master. Slaves that do not respond within\n"
+      "The timeout within which each agent is expected to respond to a\n"
+      "ping from the master. Agents that do not respond within\n"
       "max_slave_ping_timeouts ping retries will be asked to shutdown.\n"
       "NOTE: The total ping timeout (`slave_ping_timeout` multiplied by\n"
       "`max_slave_ping_timeouts`) should be greater than the ZooKeeper\n"
@@ -435,8 +435,8 @@ mesos::internal::master::Flags::Flags()
 
   add(&Flags::max_slave_ping_timeouts,
       "max_slave_ping_timeouts",
-      "The number of times a slave can fail to respond to a\n"
-      "ping from the master. Slaves that do not respond within\n"
+      "The number of times an agent can fail to respond to a\n"
+      "ping from the master. Agents that do not respond within\n"
       "`max_slave_ping_timeouts` ping retries will be asked to shutdown.\n",
       DEFAULT_MAX_SLAVE_PING_TIMEOUTS,
       [](size_t value) -> Option<Error> {

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/master/http.cpp
----------------------------------------------------------------------
diff --git a/src/master/http.cpp b/src/master/http.cpp
index d83ccd3..a9cb99a 100644
--- a/src/master/http.cpp
+++ b/src/master/http.cpp
@@ -563,9 +563,9 @@ string Master::Http::CREATE_VOLUMES_HELP()
         "Returns 202 ACCEPTED which indicates that the create",
         "operation has been validated successfully by the master.",
         "The request is then forwarded asynchronously to the Mesos",
-        "slave where the reserved resources are located.",
+        "agent where the reserved resources are located.",
         "That asynchronous message may not be delivered or",
-        "creating the volumes at the slave might fail.",
+        "creating the volumes at the agent might fail.",
         "",
         "Please provide \"slaveId\" and \"volumes\" values designating",
         "the volumes to be created."),
@@ -617,7 +617,7 @@ Future<Response> Master::Http::createVolumes(
 
   Slave* slave = master->slaves.registered.get(slaveId);
   if (slave == NULL) {
-    return BadRequest("No slave found with specified ID");
+    return BadRequest("No agent found with specified ID");
   }
 
   value = values.get("volumes");
@@ -678,9 +678,9 @@ string Master::Http::DESTROY_VOLUMES_HELP()
         "Returns 202 ACCEPTED which indicates that the destroy",
         "operation has been validated successfully by the master.",
         "The request is then forwarded asynchronously to the Mesos",
-        "slave where the reserved resources are located.",
+        "agent where the reserved resources are located.",
         "That asynchronous message may not be delivered or",
-        "destroying the volumes at the slave might fail.",
+        "destroying the volumes at the agent might fail.",
         "",
         "Please provide \"slaveId\" and \"volumes\" values designating",
         "the volumes to be destroyed."),
@@ -719,7 +719,7 @@ Future<Response> Master::Http::destroyVolumes(
 
   Slave* slave = master->slaves.registered.get(slaveId);
   if (slave == NULL) {
-    return BadRequest("No slave found with specified ID");
+    return BadRequest("No agent found with specified ID");
   }
 
   value = values.get("volumes");
@@ -1012,14 +1012,14 @@ string Master::Http::RESERVE_HELP()
 {
   return HELP(
     TLDR(
-        "Reserve resources dynamically on a specific slave."),
+        "Reserve resources dynamically on a specific agent."),
     DESCRIPTION(
         "Returns 202 ACCEPTED which indicates that the reserve",
         "operation has been validated successfully by the master.",
         "The request is then forwarded asynchronously to the Mesos",
-        "slave where the reserved resources are located.",
+        "agent where the reserved resources are located.",
         "That asynchronous message may not be delivered or",
-        "reserving resources at the slave might fail.",
+        "reserving resources at the agent might fail.",
         "",
         "Please provide \"slaveId\" and \"resources\" values designating",
         "the resources to be reserved."),
@@ -1058,7 +1058,7 @@ Future<Response> Master::Http::reserve(
 
   Slave* slave = master->slaves.registered.get(slaveId);
   if (slave == NULL) {
-    return BadRequest("No slave found with specified ID");
+    return BadRequest("No agent found with specified ID");
   }
 
   value = values.get("resources");
@@ -1115,9 +1115,9 @@ string Master::Http::SLAVES_HELP()
 {
   return HELP(
     TLDR(
-        "Information about registered slaves."),
+        "Information about registered agents."),
     DESCRIPTION(
-        "This endpoint shows information about the slaves registered in",
+        "This endpoint shows information about the agents registered in",
         "this master formatted as a JSON object."),
     AUTHENTICATION(true));
 }
@@ -1263,7 +1263,7 @@ string Master::Http::STATE_HELP()
         "Information about state of master."),
     DESCRIPTION(
         "This endpoint shows information about the frameworks, tasks,",
-        "executors and slaves running in the cluster as a JSON object.",
+        "executors and agents running in the cluster as a JSON object.",
         "",
         "Example (**Note**: this is not exhaustive):",
         "",
@@ -2478,14 +2478,14 @@ string Master::Http::UNRESERVE_HELP()
 {
   return HELP(
     TLDR(
-        "Unreserve resources dynamically on a specific slave."),
+        "Unreserve resources dynamically on a specific agent."),
     DESCRIPTION(
         "Returns 202 ACCEPTED which indicates that the unreserve",
         "operation has been validated successfully by the master.",
         "The request is then forwarded asynchronously to the Mesos",
-        "slave where the reserved resources are located.",
+        "agent where the reserved resources are located.",
         "That asynchronous message may not be delivered or",
-        "unreserving resources at the slave might fail.",
+        "unreserving resources at the agent might fail.",
         "",
         "Please provide \"slaveId\" and \"resources\" values designating",
         "the resources to be unreserved."),
@@ -2524,7 +2524,7 @@ Future<Response> Master::Http::unreserve(
 
   Slave* slave = master->slaves.registered.get(slaveId);
   if (slave == NULL) {
-    return BadRequest("No slave found with specified ID");
+    return BadRequest("No agent found with specified ID");
   }
 
   value = values.get("resources");
@@ -2580,7 +2580,7 @@ Future<Response> Master::Http::_operation(
 {
   Slave* slave = master->slaves.registered.get(slaveId);
   if (slave == NULL) {
-    return BadRequest("No slave found with specified ID");
+    return BadRequest("No agent found with specified ID");
   }
 
   // The resources recovered by rescinding outstanding offers.

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/master/master.cpp
----------------------------------------------------------------------
diff --git a/src/master/master.cpp b/src/master/master.cpp
index 210934b..6dacf5f 100644
--- a/src/master/master.cpp
+++ b/src/master/master.cpp
@@ -1769,7 +1769,7 @@ void Master::recoveredSlavesTimeout(const Registry& registry)
 
   if (removalPercentage > limit) {
     EXIT(EXIT_FAILURE)
-      << "Post-recovery slave removal limit exceeded! After "
+      << "Post-recovery agent removal limit exceeded! After "
       << flags.slave_reregister_timeout
       << " there were " << slaves.recovered.size()
       << " (" << removalPercentage * 100 << "%) agents recovered from the"
@@ -1802,7 +1802,7 @@ void Master::recoveredSlavesTimeout(const Registry& registry)
     // TODO(bmahler): With C++11, just call removeSlave from within
     // a lambda function to avoid the need to disambiguate.
     Nothing (Master::*removeSlave)(const Registry::Slave&) = &Self::removeSlave;
-    const string failure = "Slave removal rate limit acquisition failed";
+    const string failure = "Agent removal rate limit acquisition failed";
 
     acquire
       .then(defer(self(), removeSlave, slave))
@@ -1854,7 +1854,7 @@ Nothing Master::removeSlave(const Registry::Slave& slave)
     // the slave from the registry but we do not inform the
     // framework.
     const string& message =
-      "Failed to remove slave " + stringify(slave.info().id());
+      "Failed to remove agent " + stringify(slave.info().id());
 
     registrar->apply(Owned<Operation>(new RemoveSlave(slave.info())))
       .onFailed(lambda::bind(fail, message, lambda::_1));
@@ -3550,7 +3550,7 @@ void Master::_accept(
             TASK_LOST,
             TaskStatus::SOURCE_MASTER,
             None(),
-            slave == NULL ? "Slave removed" : "Slave disconnected",
+            slave == NULL ? "Agent removed" : "Agent disconnected",
             reason);
 
         metrics->tasks_lost++;
@@ -4324,7 +4324,7 @@ void Master::executorMessage(
                  << " ; asking agent to shutdown";
 
     ShutdownMessage message;
-    message.set_message("Executor message from unknown slave");
+    message.set_message("Executor message from unknown agent");
     reply(message);
     metrics->invalid_executor_to_framework_messages++;
     return;
@@ -4437,7 +4437,7 @@ void Master::registerSlave(
     LOG(WARNING) << "Refusing registration of agent at " << from
                  << " because it is not authenticated";
     ShutdownMessage message;
-    message.set_message("Slave is not authenticated");
+    message.set_message("Agent is not authenticated");
     send(from, message);
     return;
   }
@@ -4473,7 +4473,7 @@ void Master::registerSlave(
       LOG(INFO) << "Removing old disconnected agent " << *slave
                 << " because a registration attempt occurred";
       removeSlave(slave,
-                  "a new slave registered at the same address",
+                  "a new agent registered at the same address",
                   metrics->slave_removals_reason_registered);
     } else {
       CHECK(slave->active)
@@ -4547,7 +4547,7 @@ void Master::_registerSlave(
 
     ShutdownMessage message;
     message.set_message(
-        "Slave attempted to register but got duplicate slave id " +
+        "Agent attempted to register but got duplicate agent id " +
         stringify(slaveInfo.id()));
     send(pid, message);
   } else {
@@ -4618,7 +4618,7 @@ void Master::reregisterSlave(
     LOG(WARNING) << "Refusing re-registration of agent at " << from
                  << " because it is not authenticated";
     ShutdownMessage message;
-    message.set_message("Slave is not authenticated");
+    message.set_message("Agent is not authenticated");
     send(from, message);
     return;
   }
@@ -4652,7 +4652,7 @@ void Master::reregisterSlave(
                  << "re-register after removal; shutting it down";
 
     ShutdownMessage message;
-    message.set_message("Slave attempted to re-register after removal");
+    message.set_message("Agent attempted to re-register after removal");
     send(from, message);
     return;
   }
@@ -4685,7 +4685,7 @@ void Master::reregisterSlave(
 
       ShutdownMessage message;
       message.set_message(
-          "Slave attempted to re-register with different IP / hostname");
+          "Agent attempted to re-register with different IP / hostname");
 
       send(from, message);
       return;
@@ -4789,7 +4789,7 @@ void Master::_reregisterSlave(
 
     ShutdownMessage message;
     message.set_message(
-        "Slave attempted to re-register with unknown slave id " +
+        "Agent attempted to re-register with unknown agent id " +
         stringify(slaveInfo.id()));
     send(pid, message);
   } else {
@@ -4885,7 +4885,7 @@ void Master::unregisterSlave(const UPID& from, const SlaveID& slaveId)
       return;
     }
     removeSlave(slave,
-                "the slave unregistered",
+                "the agent unregistered",
                 metrics->slave_removals_reason_unregistered);
   }
 }
@@ -4907,7 +4907,7 @@ void Master::updateSlave(
       << " ; asking agent to shutdown";
 
     ShutdownMessage message;
-    message.set_message("Update slave message from unknown slave");
+    message.set_message("Update agent message from unknown agent");
     reply(message);
     return;
   }
@@ -5039,7 +5039,7 @@ void Master::statusUpdate(StatusUpdate update, const UPID& pid)
                  << " to shutdown";
 
     ShutdownMessage message;
-    message.set_message("Status update from unknown slave");
+    message.set_message("Status update from unknown agent");
     send(pid, message);
 
     metrics->invalid_status_updates++;
@@ -5143,7 +5143,7 @@ void Master::exitedExecutor(
                  << " ; asking agent to shutdown";
 
     ShutdownMessage message;
-    message.set_message("Executor exited message from unknown slave");
+    message.set_message("Executor exited message from unknown agent");
     reply(message);
     return;
   }
@@ -5434,7 +5434,7 @@ void Master::_reconcileTasks(
           TASK_LOST,
           TaskStatus::SOURCE_MASTER,
           None(),
-          "Reconciliation: Task is unknown to the slave",
+          "Reconciliation: Task is unknown to the agent",
           TaskStatus::REASON_RECONCILIATION);
     } else if (slaves.transitioning(slaveId)) {
       // (4) Task is unknown, slave is transitionary: no-op.

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/master/master.hpp
----------------------------------------------------------------------
diff --git a/src/master/master.hpp b/src/master/master.hpp
index 2dd0971..3e55114 100644
--- a/src/master/master.hpp
+++ b/src/master/master.hpp
@@ -1569,7 +1569,7 @@ protected:
     // Check and see if this slave already exists.
     if (slaveIDs->contains(info.id())) {
       if (strict) {
-        return Error("Slave already admitted");
+        return Error("Agent already admitted");
       } else {
         return false; // No mutation.
       }
@@ -1606,7 +1606,7 @@ protected:
     }
 
     if (strict) {
-      return Error("Slave not yet admitted");
+      return Error("Agent not yet admitted");
     } else {
       Registry::Slave* slave = registry->mutable_slaves()->add_slaves();
       slave->mutable_info()->CopyFrom(info);
@@ -1645,7 +1645,7 @@ protected:
     }
 
     if (strict) {
-      return Error("Slave not yet admitted");
+      return Error("Agent not yet admitted");
     } else {
       return false; // No mutation.
     }

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/master/validation.cpp
----------------------------------------------------------------------
diff --git a/src/master/validation.cpp b/src/master/validation.cpp
index 2b91446..0cd118e 100644
--- a/src/master/validation.cpp
+++ b/src/master/validation.cpp
@@ -350,8 +350,8 @@ Option<Error> validateSlaveID(const TaskInfo& task, Slave* slave)
 {
   if (task.slave_id() != slave->id) {
     return Error(
-        "Task uses invalid slave " + task.slave_id().value() +
-        " while slave " + slave->id.value() + " is expected");
+        "Task uses invalid agent " + task.slave_id().value() +
+        " while agent " + slave->id.value() + " is expected");
   }
 
   return None();
@@ -668,9 +668,9 @@ Option<Error> validateSlave(
 
     if (slave->id != slaveId.get()) {
       return Error(
-          "Aggregated offers must belong to one single slave. Offer " +
-          stringify(offerId) + " uses slave " +
-          stringify(slave->id) + " and slave " +
+          "Aggregated offers must belong to one single agent. Offer " +
+          stringify(offerId) + " uses agent " +
+          stringify(slave->id) + " and agent " +
           stringify(slaveId.get()));
     }
   }

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/python/executor/src/mesos/executor/mesos_executor_driver_impl.cpp
----------------------------------------------------------------------
diff --git a/src/python/executor/src/mesos/executor/mesos_executor_driver_impl.cpp b/src/python/executor/src/mesos/executor/mesos_executor_driver_impl.cpp
index 843771a..f2477d3 100644
--- a/src/python/executor/src/mesos/executor/mesos_executor_driver_impl.cpp
+++ b/src/python/executor/src/mesos/executor/mesos_executor_driver_impl.cpp
@@ -119,7 +119,7 @@ PyMethodDef MesosExecutorDriverImpl_methods[] = {
   { "sendFrameworkMessage",
     (PyCFunction) MesosExecutorDriverImpl_sendFrameworkMessage,
     METH_VARARGS,
-    "Send a FrameworkMessage to a slave"
+    "Send a FrameworkMessage to an agent"
   },
   { NULL }  /* Sentinel */
 };

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/python/scheduler/src/mesos/scheduler/mesos_scheduler_driver_impl.cpp
----------------------------------------------------------------------
diff --git a/src/python/scheduler/src/mesos/scheduler/mesos_scheduler_driver_impl.cpp b/src/python/scheduler/src/mesos/scheduler/mesos_scheduler_driver_impl.cpp
index 78dc298..e1c91fe 100644
--- a/src/python/scheduler/src/mesos/scheduler/mesos_scheduler_driver_impl.cpp
+++ b/src/python/scheduler/src/mesos/scheduler/mesos_scheduler_driver_impl.cpp
@@ -154,7 +154,7 @@ PyMethodDef MesosSchedulerDriverImpl_methods[] = {
   { "sendFrameworkMessage",
     (PyCFunction) MesosSchedulerDriverImpl_sendFrameworkMessage,
     METH_VARARGS,
-    "Send a FrameworkMessage to a slave"
+    "Send a FrameworkMessage to an agent"
   },
   { "reconcileTasks",
     (PyCFunction) MesosSchedulerDriverImpl_reconcileTasks,

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/scaling/scaling_sched.py
----------------------------------------------------------------------
diff --git a/src/sched/sched.cpp b/src/sched/sched.cpp
index 5f6f551..5393f0d 100644
--- a/src/sched/sched.cpp
+++ b/src/sched/sched.cpp
@@ -1443,7 +1443,7 @@ protected:
               << (status.has_uuid() ? " " + status.uuid() : "")
               << " of task " << status.task_id()
               << (status.has_slave_id()
-                  ? " on slave " + stringify(status.slave_id()) : "");
+                  ? " on agent " + stringify(status.slave_id()) : "");
     }
   }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/containerizer/mesos/isolators/network/port_mapping.cpp
----------------------------------------------------------------------
diff --git a/src/slave/containerizer/mesos/isolators/network/port_mapping.cpp b/src/slave/containerizer/mesos/isolators/network/port_mapping.cpp
index 4f3f210..ad792de 100644
--- a/src/slave/containerizer/mesos/isolators/network/port_mapping.cpp
+++ b/src/slave/containerizer/mesos/isolators/network/port_mapping.cpp
@@ -2483,7 +2483,7 @@ Future<Option<ContainerLaunchInfo>> PortMappingIsolatorProcess::prepare(
         return Failure(
             "Some non-ephemeral ports specified in " +
             stringify(nonEphemeralPorts) +
-            " are not managed by the slave");
+            " are not managed by the agent");
     }
   }
 
@@ -2967,7 +2967,7 @@ Future<Nothing> PortMappingIsolatorProcess::update(
         return Failure(
             "Some non-ephemeral ports specified in " +
             stringify(nonEphemeralPorts) +
-            " are not managed by the slave");
+            " are not managed by the agent");
     }
   }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/flags.cpp
----------------------------------------------------------------------
diff --git a/src/slave/flags.cpp b/src/slave/flags.cpp
index 316feec..10d2974 100644
--- a/src/slave/flags.cpp
+++ b/src/slave/flags.cpp
@@ -33,9 +33,9 @@ mesos::internal::slave::Flags::Flags()
 {
   add(&Flags::hostname,
       "hostname",
-      "The hostname the slave should report.\n"
+      "The hostname the agent should report.\n"
       "If left unset, the hostname is resolved from the IP address\n"
-      "that the slave binds to; unless the user explicitly prevents\n"
+      "that the agent binds to; unless the user explicitly prevents\n"
       "that, using `--no-hostname_lookup`, in which case the IP itself\n"
       "is used.");
 
@@ -55,7 +55,7 @@ mesos::internal::slave::Flags::Flags()
   // TODO(benh): Is there a way to specify units for the resources?
   add(&Flags::resources,
       "resources",
-      "Total consumable resources per slave. Can be provided in JSON format\n"
+      "Total consumable resources per agent. Can be provided in JSON format\n"
       "or as a semicolon-delimited list of key:value pairs, with the role\n"
       "optionally specified.\n"
       "\n"
@@ -102,7 +102,7 @@ mesos::internal::slave::Flags::Flags()
       "The launcher to be used for Mesos containerizer. It could either be\n"
       "`linux` or `posix`. The Linux launcher is required for cgroups\n"
       "isolation and for any isolators that require Linux namespaces such as\n"
-      "network, pid, etc. If unspecified, the slave will choose the Linux\n"
+      "network, pid, etc. If unspecified, the agent will choose the Linux\n"
       "launcher if it's running as root on Linux.");
 
   add(&Flags::image_providers,
@@ -151,7 +151,7 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::attributes,
       "attributes",
-      "Attributes of the slave machine, in the form:\n"
+      "Attributes of the agent machine, in the form:\n"
       "`rack:2` or `rack:2;u:1`");
 
   add(&Flags::fetcher_cache_size,
@@ -170,7 +170,7 @@ mesos::internal::slave::Flags::Flags()
   add(&Flags::fetcher_cache_dir,
       "fetcher_cache_dir",
       "Parent directory for fetcher cache directories\n"
-      "(one subdirectory per slave).",
+      "(one subdirectory per agent).",
       "/tmp/mesos/fetch");
 
   add(&Flags::work_dir,
@@ -195,14 +195,14 @@ mesos::internal::slave::Flags::Flags()
 #ifndef __WINDOWS__
   add(&Flags::switch_user,
       "switch_user",
-      "If set to `true`, the slave will attempt to run tasks as\n"
+      "If set to `true`, the agent will attempt to run tasks as\n"
       "the `user` who submitted them (as defined in `FrameworkInfo`)\n"
       "(this requires `setuid` permission and that the given `user`\n"
-      "exists on the slave).\n"
+      "exists on the agent).\n"
       "If the user does not exist, an error occurs and the task will fail.\n"
       "If set to `false`, tasks will be run as the same user as the Mesos\n"
-      "slave process.\n"
-      "NOTE: This feature is not yet supported on Windows slave, and\n"
+      "agent process.\n"
+      "NOTE: This feature is not yet supported on Windows agent, and\n"
       "therefore the flag currently does not exist on that platform.",
       true);
 #endif // __WINDOWS__
@@ -213,7 +213,7 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::registration_backoff_factor,
       "registration_backoff_factor",
-      "Slave initially picks a random amount of time between `[0, b]`, where\n"
+      "Agent initially picks a random amount of time between `[0, b]`, where\n"
       "`b = registration_backoff_factor`, to (re-)register with a new master.\n"
       "Subsequent retries are exponentially backed off based on this\n"
       "interval (e.g., 1st retry uses a random value between `[0, b * 2^1]`,\n"
@@ -226,7 +226,7 @@ mesos::internal::slave::Flags::Flags()
       "executor_environment_variables",
       "JSON object representing the environment variables that should be\n"
       "passed to the executor, and thus subsequently task(s). By default the\n"
-      "executor will inherit the slave's environment variables.\n"
+      "executor will inherit the agent's environment variables.\n"
       "Example:\n"
       "{\n"
       "  \"PATH\": \"/bin:/usr/bin\",\n"
@@ -247,7 +247,7 @@ mesos::internal::slave::Flags::Flags()
   add(&Flags::executor_registration_timeout,
       "executor_registration_timeout",
       "Amount of time to wait for an executor\n"
-      "to register with the slave before considering it hung and\n"
+      "to register with the agent before considering it hung and\n"
       "shutting it down (e.g., 60secs, 3mins, etc)",
       EXECUTOR_REGISTRATION_TIMEOUT);
 
@@ -281,7 +281,7 @@ mesos::internal::slave::Flags::Flags()
   add(&Flags::disk_watch_interval,
       "disk_watch_interval",
       "Periodic time interval (e.g., 10secs, 2mins, etc)\n"
-      "to check the overall disk usage managed by the slave.\n"
+      "to check the overall disk usage managed by the agent.\n"
       "This drives the garbage collection of archived\n"
       "information and sandboxes.",
       DISK_WATCH_INTERVAL);
@@ -299,22 +299,22 @@ mesos::internal::slave::Flags::Flags()
       "Valid values for `recover` are\n"
       "reconnect: Reconnect with any old live executors.\n"
       "cleanup  : Kill any old live executors and exit.\n"
-      "           Use this option when doing an incompatible slave\n"
+      "           Use this option when doing an incompatible agent\n"
       "           or executor upgrade!).",
       "reconnect");
 
   add(&Flags::recovery_timeout,
       "recovery_timeout",
-      "Amount of time allotted for the slave to recover. If the slave takes\n"
+      "Amount of time allotted for the agent to recover. If the agent takes\n"
       "longer than recovery_timeout to recover, any executors that are\n"
-      "waiting to reconnect to the slave will self-terminate.\n",
+      "waiting to reconnect to the agent will self-terminate.\n",
       RECOVERY_TIMEOUT);
 
   add(&Flags::strict,
       "strict",
       "If `strict=true`, any and all recovery errors are considered fatal.\n"
-      "If `strict=false`, any expected errors (e.g., slave cannot recover\n"
-      "information about an executor, because the slave died right before\n"
+      "If `strict=false`, any expected errors (e.g., agent cannot recover\n"
+      "information about an executor, because the agent died right before\n"
       "the executor registered.) during recovery are ignored and as much\n"
       "state as possible is recovered.\n",
       true);
@@ -361,7 +361,7 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::slave_subsystems,
       "slave_subsystems",
-      "List of comma-separated cgroup subsystems to run the slave binary\n"
+      "List of comma-separated cgroup subsystems to run the agent binary\n"
       "in, e.g., `memory,cpuacct`. The default is none.\n"
       "Present functionality is intended for resource monitoring and\n"
       "no cgroup limits are set, they are inherited from the root mesos\n"
@@ -479,29 +479,29 @@ mesos::internal::slave::Flags::Flags()
       "docker_kill_orphans",
       "Enable docker containerizer to kill orphaned containers.\n"
       "You should consider setting this to false when you launch multiple\n"
-      "slaves in the same OS, to avoid one of the DockerContainerizer \n"
-      "removing docker tasks launched by other slaves.\n",
+      "agents in the same OS, to avoid one of the DockerContainerizer \n"
+      "removing docker tasks launched by other agents.\n",
       true);
 
   add(&Flags::docker_mesos_image,
       "docker_mesos_image",
-      "The Docker image used to launch this Mesos slave instance.\n"
-      "If an image is specified, the docker containerizer assumes the slave\n"
+      "The Docker image used to launch this Mesos agent instance.\n"
+      "If an image is specified, the docker containerizer assumes the agent\n"
       "is running in a docker container, and launches executors with\n"
-      "docker containers in order to recover them when the slave restarts and\n"
+      "docker containers in order to recover them when the agent restarts and\n"
       "recovers.\n");
 
   add(&Flags::docker_socket,
       "docker_socket",
       "The UNIX socket path to be mounted into the docker executor container\n"
       "to provide docker CLI access to the docker daemon. This must be the\n"
-      "path used by the slave's docker image.\n",
+      "path used by the agent's docker image.\n",
       "/var/run/docker.sock");
 
   add(&Flags::docker_config,
       "docker_config",
-      "The default docker config file for slave. Can be provided either as a\n"
-      "path pointing to the slave local docker config file, or as a\n"
+      "The default docker config file for agent. Can be provided either as a\n"
+      "path pointing to the agent local docker config file, or as a\n"
       "JSON-formatted string. The format of the docker config file should be\n"
       "identical to docker's default one (e.g., either\n"
       "`~/.docker/config.json` or `~/.dockercfg`).\n"
@@ -730,7 +730,7 @@ mesos::internal::slave::Flags::Flags()
   add(&Flags::http_credentials,
       "http_credentials",
       "Path to a JSON-formatted file containing credentials used to\n"
-      "authenticate HTTP endpoints on the slave.\n"
+      "authenticate HTTP endpoints on the agent.\n"
       "Path can be of the form `file:///path/to/file` or `/path/to/file`.\n"
       "Example:\n"
       "{\n"
@@ -745,7 +745,7 @@ mesos::internal::slave::Flags::Flags()
   add(&Flags::hooks,
       "hooks",
       "A comma-separated list of hook modules to be\n"
-      "installed inside the slave.");
+      "installed inside the agent.");
 
   add(&Flags::resource_estimator,
       "resource_estimator",
@@ -757,7 +757,7 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::qos_correction_interval_min,
       "qos_correction_interval_min",
-      "The slave polls and carries out QoS corrections from the QoS\n"
+      "The agent polls and carries out QoS corrections from the QoS\n"
       "Controller based on its observed performance of running tasks.\n"
       "The smallest interval between these corrections is controlled by\n"
       "this flag.",
@@ -765,7 +765,7 @@ mesos::internal::slave::Flags::Flags()
 
   add(&Flags::oversubscribed_resources_interval,
       "oversubscribed_resources_interval",
-      "The slave periodically updates the master with the current estimation\n"
+      "The agent periodically updates the master with the current estimation\n"
       "about the total amount of oversubscribed resources that are allocated\n"
       "and available. The interval between updates is controlled by this\n"
       "flag.",

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/http.cpp
----------------------------------------------------------------------
diff --git a/src/slave/http.cpp b/src/slave/http.cpp
index 3f96f2c..3908e33 100644
--- a/src/slave/http.cpp
+++ b/src/slave/http.cpp
@@ -368,9 +368,9 @@ string Slave::Http::HEALTH_HELP()
 {
   return HELP(
     TLDR(
-        "Health check of the Slave."),
+        "Health check of the Agent."),
     DESCRIPTION(
-        "Returns 200 OK iff the Slave is healthy.",
+        "Returns 200 OK iff the Agent is healthy.",
         "Delayed responses are also indicative of poor health."),
     AUTHENTICATION(false));
 }
@@ -385,10 +385,10 @@ Future<Response> Slave::Http::health(const Request& request) const
 string Slave::Http::STATE_HELP() {
   return HELP(
     TLDR(
-        "Information about state of the Slave."),
+        "Information about state of the Agent."),
     DESCRIPTION(
         "This endpoint shows information about the frameworks, executors",
-        "and the slave's master as a JSON object.",
+        "and the agent's master as a JSON object.",
         "",
         "Example (**Note**: this is not exhaustive):",
         "",
@@ -561,7 +561,7 @@ string Slave::Http::STATISTICS_HELP()
           "Retrieve resource monitoring information."),
       DESCRIPTION(
           "Returns the current resource consumption data for containers",
-          "running under this slave.",
+          "running under this agent.",
           "",
           "Example:",
           "",

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/main.cpp
----------------------------------------------------------------------
diff --git a/src/slave/main.cpp b/src/slave/main.cpp
index 70df4f3..38bd005 100644
--- a/src/slave/main.cpp
+++ b/src/slave/main.cpp
@@ -116,17 +116,17 @@ int main(int argc, char** argv)
   Option<string> advertise_ip;
   flags.add(&advertise_ip,
             "advertise_ip",
-            "IP address advertised to reach this Mesos slave.\n"
-            "The slave does not bind to this IP address.\n"
-            "However, this IP address may be used to access this slave.");
+            "IP address advertised to reach this Mesos agent.\n"
+            "The agent does not bind to this IP address.\n"
+            "However, this IP address may be used to access this agent.");
 
   Option<string> advertise_port;
   flags.add(&advertise_port,
             "advertise_port",
-            "Port advertised to reach this Mesos slave (along with\n"
-            "`advertise_ip`). The slave does not bind to this port.\n"
+            "Port advertised to reach this Mesos agent (along with\n"
+            "`advertise_ip`). The agent does not bind to this port.\n"
             "However, this port (along with `advertise_ip`) may be used to\n"
-            "access this slave.");
+            "access this agent.");
 
   Option<string> master;
   flags.add(&master,
@@ -144,7 +144,7 @@ int main(int argc, char** argv)
   flags.add(&ip_discovery_command,
             "ip_discovery_command",
             "Optional IP discovery binary: if set, it is expected to emit\n"
-            "the IP address which the slave will try to bind to.\n"
+            "the IP address which the agent will try to bind to.\n"
             "Cannot be used in conjunction with `--ip`.");
 
   Try<Nothing> load = flags.load("MESOS_", argc, argv);

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/slave.cpp
----------------------------------------------------------------------
diff --git a/src/slave/slave.cpp b/src/slave/slave.cpp
index de99e9e..d82dec2 100644
--- a/src/slave/slave.cpp
+++ b/src/slave/slave.cpp
@@ -1308,7 +1308,7 @@ void Slave::reregistered(
             TASK_LOST,
             TaskStatus::SOURCE_SLAVE,
             UUID::random(),
-            "Reconciliation: task unknown to the slave",
+            "Reconciliation: task unknown to the agent",
             TaskStatus::REASON_RECONCILIATION);
 
         // NOTE: We can't use statusUpdate() here because it drops
@@ -1737,7 +1737,7 @@ void Slave::_runTask(
           TaskStatus::SOURCE_SLAVE,
           UUID::random(),
           "The checkpointed resources being used by the task are unknown to "
-          "the slave",
+          "the agent",
           TaskStatus::REASON_RESOURCES_UNKNOWN);
 
       statusUpdate(update, UPID());
@@ -1770,7 +1770,7 @@ void Slave::_runTask(
             TaskStatus::SOURCE_SLAVE,
             UUID::random(),
             "The checkpointed resources being used by the executor are unknown "
-            "to the slave",
+            "to the agent",
             TaskStatus::REASON_RESOURCES_UNKNOWN,
             task.executor().executor_id());
 
@@ -2816,7 +2816,7 @@ void Slave::subscribe(
               TASK_LOST,
               TaskStatus::SOURCE_SLAVE,
               UUID::random(),
-              "Task launched during slave restart",
+              "Task launched during agent restart",
               TaskStatus::REASON_SLAVE_RESTARTED,
               executor->id);
 
@@ -3085,7 +3085,7 @@ void Slave::reregisterExecutor(
               TASK_LOST,
               TaskStatus::SOURCE_SLAVE,
               UUID::random(),
-              "Task launched during slave restart",
+              "Task launched during agent restart",
               TaskStatus::REASON_SLAVE_RESTARTED,
               executorId);
 
@@ -4655,7 +4655,7 @@ Future<Nothing> Slave::recover(const Result<state::State>& state)
       return Failure(
           "Checkpointed resources " +
           stringify(resourcesState.get().resources) +
-          " are incompatible with slave resources " +
+          " are incompatible with agent resources " +
           stringify(info.resources()) + ": " +
           totalResources.error());
     }
@@ -4674,11 +4674,11 @@ Future<Nothing> Slave::recover(const Result<state::State>& state)
         !(info == slaveState.get().info.get())) {
       return Failure(strings::join(
           "\n",
-          "Incompatible slave info detected.",
+          "Incompatible agent info detected.",
           "------------------------------------------------------------",
-          "Old slave info:\n" + stringify(slaveState.get().info.get()),
+          "Old agent info:\n" + stringify(slaveState.get().info.get()),
           "------------------------------------------------------------",
-          "New slave info:\n" + stringify(info),
+          "New agent info:\n" + stringify(info),
           "------------------------------------------------------------"));
     }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/slave/state.cpp
----------------------------------------------------------------------
diff --git a/src/slave/state.cpp b/src/slave/state.cpp
index e7b44c7..04c3d42 100644
--- a/src/slave/state.cpp
+++ b/src/slave/state.cpp
@@ -104,7 +104,7 @@ Result<State> recover(const string& rootDir, bool strict)
   // Get the latest slave id.
   Result<string> directory = os::realpath(latest);
   if (!directory.isSome()) {
-    return Error("Failed to find latest slave: " +
+    return Error("Failed to find latest agent: " +
                  (directory.isError()
                   ? directory.error()
                   : "No such file or directory"));
@@ -144,7 +144,7 @@ Try<SlaveState> SlaveState::recover(
   const Result<SlaveInfo>& slaveInfo = ::protobuf::read<SlaveInfo>(path);
 
   if (slaveInfo.isError()) {
-    const string& message = "Failed to read slave info from '" + path + "': " +
+    const string& message = "Failed to read agent info from '" + path + "': " +
                             slaveInfo.error();
     if (strict) {
       return Error(message);
@@ -168,7 +168,7 @@ Try<SlaveState> SlaveState::recover(
   Try<list<string> > frameworks = paths::getFrameworkPaths(rootDir, slaveId);
 
   if (frameworks.isError()) {
-    return Error("Failed to find frameworks for slave " + slaveId.value() +
+    return Error("Failed to find frameworks for agent " + slaveId.value() +
                  ": " + frameworks.error());
   }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/cluster.cpp
----------------------------------------------------------------------
diff --git a/src/tests/cluster.cpp b/src/tests/cluster.cpp
index b4d6910..31d2556 100644
--- a/src/tests/cluster.cpp
+++ b/src/tests/cluster.cpp
@@ -238,7 +238,7 @@ Try<process::Owned<Master>> Master::start(
       return Error(
           "Invalid slave_removal_rate_limit: " +
           flags.slave_removal_rate_limit.get() +
-          ". Format is <Number of slaves>/<Duration>");
+          ". Format is <Number of agents>/<Duration>");
     }
 
     Try<int> permits = numify<int>(tokens[0]);
@@ -246,7 +246,7 @@ Try<process::Owned<Master>> Master::start(
       return Error(
           "Invalid slave_removal_rate_limit: " +
           flags.slave_removal_rate_limit.get() +
-          ". Format is <Number of slaves>/<Duration>: " + permits.error());
+          ". Format is <Number of agents>/<Duration>: " + permits.error());
     }
 
     Try<Duration> duration = Duration::parse(tokens[1]);
@@ -254,7 +254,7 @@ Try<process::Owned<Master>> Master::start(
       return Error(
           "Invalid slave_removal_rate_limit: " +
           flags.slave_removal_rate_limit.get() +
-          ". Format is <Number of slaves>/<Duration>: " + duration.error());
+          ". Format is <Number of agents>/<Duration>: " + duration.error());
     }
 
     master->slaveRemovalLimiter =
@@ -525,7 +525,7 @@ void Slave::wait()
       Try<Nothing> assign = cgroups::assign(hierarchy, "", getpid());
       if (assign.isError()) {
         EXIT(EXIT_FAILURE)
-          << "Failed to move slave threads into cgroup " << cgroup
+          << "Failed to move agent threads into cgroup " << cgroup
           << " for subsystem " << subsystem
           << " under hierarchy " << hierarchy
           << " for agent: " + assign.error();

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/containerizer/docker_containerizer_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/docker_containerizer_tests.cpp b/src/tests/containerizer/docker_containerizer_tests.cpp
index 7accd32..f431653 100644
--- a/src/tests/containerizer/docker_containerizer_tests.cpp
+++ b/src/tests/containerizer/docker_containerizer_tests.cpp
@@ -1275,7 +1275,7 @@ TEST_F(DockerContainerizerTest, ROOT_DOCKER_KillOrphanContainers)
   slaveId.set_value("s1");
 
   SlaveID oldSlaveId;
-  oldSlaveId.set_value("old-slave-id");
+  oldSlaveId.set_value("old-agent-id");
 
   ContainerID containerId;
   containerId.set_value(UUID::random().toString());

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/containerizer/filesystem_isolator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/containerizer/filesystem_isolator_tests.cpp b/src/tests/containerizer/filesystem_isolator_tests.cpp
index 51e60c2..29d3130 100644
--- a/src/tests/containerizer/filesystem_isolator_tests.cpp
+++ b/src/tests/containerizer/filesystem_isolator_tests.cpp
@@ -1240,7 +1240,7 @@ TEST_F(LinuxFilesystemIsolatorTest, ROOT_MultipleContainers)
   ASSERT_SOME(containerizer);
 
   SlaveID slaveId;
-  slaveId.set_value("test_slave");
+  slaveId.set_value("test_agent");
 
   // First launch container 1 which has a long running task which
   // guarantees that its work directory mount is in the host mount

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/flags.hpp
----------------------------------------------------------------------
diff --git a/src/tests/flags.hpp b/src/tests/flags.hpp
index af15360..ae232b1 100644
--- a/src/tests/flags.hpp
+++ b/src/tests/flags.hpp
@@ -80,7 +80,7 @@ public:
         "The UNIX socket path to be mounted into the\n"
         "docker executor container to provide docker\n"
         "CLI access to the docker daemon. This must be the\n"
-        "path used by the slave's docker image.\n",
+        "path used by the agent's docker image.\n",
         "/var/run/docker.sock");
 
     // This help message for --modules flag is the same for
@@ -145,7 +145,7 @@ public:
     add(&Flags::authenticators,
         "authenticators",
         "Authenticator implementation to use when authenticating frameworks\n"
-        "and/or slaves. Use the default '" +
+        "and/or agents. Use the default '" +
         std::string(master::DEFAULT_AUTHENTICATOR) + "', or\n"
         "load an alternate authenticator module using --modules.",
         master::DEFAULT_AUTHENTICATOR);

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/hierarchical_allocator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/hierarchical_allocator_tests.cpp b/src/tests/hierarchical_allocator_tests.cpp
index 8ed0df4..53a759c 100644
--- a/src/tests/hierarchical_allocator_tests.cpp
+++ b/src/tests/hierarchical_allocator_tests.cpp
@@ -184,7 +184,7 @@ protected:
   SlaveInfo createSlaveInfo(const string& resources)
   {
     SlaveID slaveId;
-    slaveId.set_value("slave" + stringify(nextSlaveId++));
+    slaveId.set_value("agent" + stringify(nextSlaveId++));
 
     SlaveInfo slave;
     *(slave.mutable_resources()) = Resources::parse(resources).get();
@@ -1324,7 +1324,7 @@ TEST_F(HierarchicalAllocatorTest, Whitelist)
   initialize();
 
   hashset<string> whitelist;
-  whitelist.insert("dummy-slave");
+  whitelist.insert("dummy-agent");
 
   allocator->updateWhitelist(whitelist);
 
@@ -3350,7 +3350,7 @@ TEST_P(HierarchicalAllocator_BENCHMARK_Test, Metrics)
   watch.stop();
 
   cout << "/metrics/snapshot took " << watch.elapsed()
-       << " for " << slaveCount << " slaves"
+       << " for " << slaveCount << " agents"
        << " and " << frameworkCount << " frameworks" << endl;
 }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/master_allocator_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_allocator_tests.cpp b/src/tests/master_allocator_tests.cpp
index 17607df..bb96b25 100644
--- a/src/tests/master_allocator_tests.cpp
+++ b/src/tests/master_allocator_tests.cpp
@@ -1143,7 +1143,7 @@ TYPED_TEST(MasterAllocatorTest, Whitelist)
 
   // Create a dummy whitelist, so that no resources will get allocated.
   hashset<string> hosts;
-  hosts.insert("dummy-slave1");
+  hosts.insert("dummy-agent1");
 
   const string path = "whitelist.txt";
   ASSERT_SOME(os::write(path, strings::join("\n", hosts)));
@@ -1169,7 +1169,7 @@ TYPED_TEST(MasterAllocatorTest, Whitelist)
 
   // Update the whitelist to ensure that the change is sent
   // to the allocator.
-  hosts.insert("dummy-slave2");
+  hosts.insert("dummy-agent2");
 
   Future<Nothing> updateWhitelist2;
   EXPECT_CALL(allocator, updateWhitelist(Option<hashset<string>>(hosts)))

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/master_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_tests.cpp b/src/tests/master_tests.cpp
index cdd69b6..8e00753 100644
--- a/src/tests/master_tests.cpp
+++ b/src/tests/master_tests.cpp
@@ -1094,7 +1094,7 @@ TEST_F(WhitelistTest, WhitelistSlave)
   Try<string> hostname = net::hostname();
   ASSERT_SOME(hostname);
 
-  string hosts = hostname.get() + "\n" + "dummy-slave";
+  string hosts = hostname.get() + "\n" + "dummy-agent";
   ASSERT_SOME(os::write(path, hosts)) << "Error writing whitelist";
 
   master::Flags flags = CreateMasterFlags();

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/paths_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/paths_tests.cpp b/src/tests/paths_tests.cpp
index 81498e3..0671ee2 100644
--- a/src/tests/paths_tests.cpp
+++ b/src/tests/paths_tests.cpp
@@ -43,7 +43,7 @@ class PathsTest : public ::testing::Test
 public:
   virtual void SetUp()
   {
-    slaveId.set_value("slave1");
+    slaveId.set_value("agent1");
     frameworkId.set_value("framework1");
     executorId.set_value("executor1");
     taskId.set_value("task1");

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/slave_recovery_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/slave_recovery_tests.cpp b/src/tests/slave_recovery_tests.cpp
index 7913234..8ad6322 100644
--- a/src/tests/slave_recovery_tests.cpp
+++ b/src/tests/slave_recovery_tests.cpp
@@ -113,7 +113,7 @@ TEST_F(SlaveStateTest, CheckpointProtobufMessage)
 {
   // Checkpoint slave id.
   SlaveID expected;
-  expected.set_value("slave1");
+  expected.set_value("agent1");
 
   const string& file = "slave.id";
   slave::state::checkpoint(file, expected);
@@ -439,7 +439,7 @@ TYPED_TEST(SlaveRecoveryTest, ReconnectHTTPExecutor)
 
   // Start the slave with a static process ID. This allows the executor to
   // reconnect with the slave upon a process restart.
-  const std::string id("slave");
+  const std::string id("agent");
 
   Owned<MasterDetector> detector = master.get()->createDetector();
 
@@ -1065,7 +1065,7 @@ TYPED_TEST(SlaveRecoveryTest, CleanupHTTPExecutor)
 
   // Start the slave with a static process ID. This allows the executor to
   // reconnect with the slave upon a process restart.
-  const std::string id("slave");
+  const std::string id("agent");
 
   Owned<MasterDetector> detector = master.get()->createDetector();
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/tests/sorter_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/sorter_tests.cpp b/src/tests/sorter_tests.cpp
index 0f3266f..eb207a3 100644
--- a/src/tests/sorter_tests.cpp
+++ b/src/tests/sorter_tests.cpp
@@ -45,7 +45,7 @@ TEST(SorterTest, DRFSorter)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   Resources totalResources = Resources::parse("cpus:100;mem:100").get();
   sorter.add(slaveId, totalResources);
@@ -129,7 +129,7 @@ TEST(SorterTest, WDRFSorter)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   sorter.add(slaveId, Resources::parse("cpus:100;mem:100").get());
 
@@ -184,7 +184,7 @@ TEST(SorterTest, SplitResourceShares)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   sorter.add("a");
   sorter.add("b");
@@ -217,7 +217,7 @@ TEST(SorterTest, UpdateAllocation)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   sorter.add("a");
   sorter.add("b");
@@ -257,10 +257,10 @@ TEST(SorterTest, MultipleSlaves)
   DRFSorter sorter;
 
   SlaveID slaveA;
-  slaveA.set_value("slaveA");
+  slaveA.set_value("agentA");
 
   SlaveID slaveB;
-  slaveB.set_value("slaveB");
+  slaveB.set_value("agentB");
 
   sorter.add("framework");
 
@@ -289,10 +289,10 @@ TEST(SorterTest, MultipleSlavesUpdateAllocation)
   DRFSorter sorter;
 
   SlaveID slaveA;
-  slaveA.set_value("slaveA");
+  slaveA.set_value("agentA");
 
   SlaveID slaveB;
-  slaveB.set_value("slaveB");
+  slaveB.set_value("agentB");
 
   sorter.add("framework");
 
@@ -331,7 +331,7 @@ TEST(SorterTest, UpdateTotal)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   sorter.add("a");
   sorter.add("b");
@@ -370,10 +370,10 @@ TEST(SorterTest, MultipleSlavesUpdateTotal)
   DRFSorter sorter;
 
   SlaveID slaveA;
-  slaveA.set_value("slaveA");
+  slaveA.set_value("agentA");
 
   SlaveID slaveB;
-  slaveB.set_value("slaveB");
+  slaveB.set_value("agentB");
 
   sorter.add("a");
   sorter.add("b");
@@ -413,7 +413,7 @@ TEST(SorterTest, RevocableResources)
   DRFSorter sorter;
 
   SlaveID slaveId;
-  slaveId.set_value("slaveId");
+  slaveId.set_value("agentId");
 
   sorter.add("a");
   sorter.add("b");


[2/2] mesos git commit: Slave rename - Updated standard output messages in libprocess.

Posted by vi...@apache.org.
Slave rename - Updated standard output messages in libprocess.

Renamed 'slave' to 'agent' in the standard output messages of
libprocess

Review: https://reviews.apache.org/r/46190/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/5c1782b0
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/5c1782b0
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/5c1782b0

Branch: refs/heads/master
Commit: 5c1782b004fd79392a59228ec14dd37154097ed0
Parents: 02c00e2
Author: zhou xing <xi...@cn.ibm.com>
Authored: Sun Apr 17 19:34:16 2016 -0700
Committer: Vinod Kone <vi...@gmail.com>
Committed: Sun Apr 17 19:34:16 2016 -0700

----------------------------------------------------------------------
 3rdparty/libprocess/src/test-master.cpp |  4 ++--
 3rdparty/libprocess/src/test-slave.cpp  | 12 ++++++------
 2 files changed, 8 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/5c1782b0/3rdparty/libprocess/src/test-master.cpp
----------------------------------------------------------------------
diff --git a/3rdparty/libprocess/src/test-master.cpp b/3rdparty/libprocess/src/test-master.cpp
index 03f2f83..5026af3 100644
--- a/3rdparty/libprocess/src/test-master.cpp
+++ b/3rdparty/libprocess/src/test-master.cpp
@@ -37,7 +37,7 @@ protected:
         string name;
         unpack<REGISTER>(name);
 
-        Out::println("Registered slave: %s", name.c_str());
+        Out::println("Registered agent: %s", name.c_str());
 
         send(from(), pack<OKAY>(id++));
         break;
@@ -48,7 +48,7 @@ protected:
         int slave_id;
         unpack<UNREGISTER>(slave_id);
 
-        Out::println("Unregistered slave id: %d", slave_id);
+        Out::println("Unregistered agent id: %d", slave_id);
 
         send(from(), pack<OKAY>(0));
         break;

http://git-wip-us.apache.org/repos/asf/mesos/blob/5c1782b0/3rdparty/libprocess/src/test-slave.cpp
----------------------------------------------------------------------
diff --git a/3rdparty/libprocess/src/test-slave.cpp b/3rdparty/libprocess/src/test-slave.cpp
index 9797792..4516bdc 100644
--- a/3rdparty/libprocess/src/test-slave.cpp
+++ b/3rdparty/libprocess/src/test-slave.cpp
@@ -27,13 +27,13 @@ protected:
 
     switch (receive()) {
     case OKAY: {
-      std::cout << "slave registered" << std::endl;
+      std::cout << "agent registered" << std::endl;
       unpack<OKAY>(id);
-      std::cout << "slave id: " << id << std::endl;
+      std::cout << "agent id: " << id << std::endl;
       break;
     }
     default:
-      std::cout << "slave failed to register" << std::endl;
+      std::cout << "agent failed to register" << std::endl;
       break;
     }
 
@@ -41,10 +41,10 @@ protected:
 
     switch (receive()) {
     case OKAY:
-      std::cout << "slave unregistered" << std::endl;
+      std::cout << "agent unregistered" << std::endl;
       break;
     default:
-      std::cout << "slave failed to unregister" << std::endl;
+      std::cout << "agent failed to unregister" << std::endl;
       break;
     }
 
@@ -68,6 +68,6 @@ int main(int argc, char **argv)
 {
   PID master = make_pid(argv[1]);
   PID slave = Process::spawn(new Slave(master));
-  std::cout << "slave is at " << slave << std::endl;
+  std::cout << "agent is at " << slave << std::endl;
   Process::wait(slave);
 }
diff --git a/src/scaling/scaling_sched.py b/src/scaling/scaling_sched.py
index d1008c7..011e353 100755
--- a/src/scaling/scaling_sched.py
+++ b/src/scaling/scaling_sched.py
@@ -62,7 +62,7 @@ class ScalingScheduler(mesos.Scheduler):
   def resourceOffer(self, driver, oid, offers):
     # Make sure the nested schedulers can actually run their tasks.
     # if len(offers) <= len(config) and len(config) != self.tid:
     #   print "Need at least one spare slave to do this work ... exiting!"
     #   driver.stop()
     #   return
 
@@ -78,7 +78,7 @@ class ScalingScheduler(mesos.Scheduler):
         tasks.append(task)
         self.running[self.tid] = (todo, duration)
         self.tid += 1
-        print "Launching (%d, %d) on slave %s" % (todo, duration, offer.slaveId)
+        print "Launching (%d, %d) on agent %s" % (todo, duration, offer.slaveId)
     driver.launchTasks(oid, tasks)
 
   def statusUpdate(self, driver, status):

http://git-wip-us.apache.org/repos/asf/mesos/blob/02c00e2c/src/sched/sched.cpp
----------------------------------------------------------------------
@@ -62,7 +62,7 @@ class ScalingScheduler(mesos.Scheduler):
     # Make sure the nested schedulers can actually run their tasks.
     # if len(offers) <= len(config) and len(config) != self.tid:
-    #   print "Need at least one spare slave to do this work ... exiting!"
+    #   print "Need at least one spare agent to do this work ... exiting!"
     #   driver.stop()
     #   return